#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# File              : utils.py
# Author            : JCHRYS <jchrys@me.com>
# Date              : 04.01.2020
# Last Modified Date: 04.01.2020
# Last Modified By  : JCHRYS <jchrys@me.com>
import re
import requests
from bs4 import BeautifulSoup


re_all = re.compile('<[^>]*>')
def drop_html_tag_all(html):
    if html == None:
        return None
    #print(type(html))
    return re.sub(re_all, '', html)

def get_drop_html_tag_but(tag):
    regex = '(?!</?' + tag + '>)<.*?>'
    #print(regex)
    _re = re.compile(regex)
    def drop_html_tag(html):
        return re.sub(_re, '', html)
    return drop_html_tag 



def get_html_content_by_id(url, ids=[]) -> dict:
    if not isinstance(ids, list):
        raise Exception("not a list")
    res = requests.get(url)
    soup = BeautifulSoup(res.content, 'html.parser')
    return { id: soup.find(id=id).text if soup.find(id=id) else None for id in ids }

if __name__ == '__main__':
    print(drop_html_tag_all("<strong> Hello World!</strong>"))
    br_cleaner = get_drop_html_tag_but('all')
    print(br_cleaner("<br>GOOODDADSAD<br>>"))
    detail_url = 'http://book.naver.com/bookdb/book_detail.php?bid=15433261'
    print(get_html_content_by_id(detail_url, 
        ['authorIntroContent', 'bookIntroContent', 'tableOfContentsContent']))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# File              : main.py
# Author            : JCHRYS <jchrys@me.com>
# Date              : 04.01.2020
# Last Modified Date: 06.01.2020
# Last Modified By  : JCHRYS <jchrys@me.com>
import settings
import platform
import time
import json
import os
from tqdm import tqdm
from nbs.core import utils
from nbs.core.requester import Request

from pprint import pprint

## os_validation ##
if (platform.system() != 'Darwin'):
    print('Your OS is not supported')
    exit()
##TODO header, params, url 
request = Request(settings.default_headers, settings.default_params, settings.default_url)
output_filename = input('output_filename: ')
keyword_count = input('how many keywords? ')
keywords = []
for i in range(int(keyword_count)):
    keywords.append(input('keywords No.' + str(i+1) + ' '))
res_json = []
for keyword in tqdm(keywords, leave=True, desc='total', ncols=80):
    res = request.search(keyword).json()
    detail_ids = ['authorIntroContent', 'bookIntroContent', 'tableOfContentsContent']
    items = res['items']

    for item in tqdm(items, desc=keyword, leave=False, ncols=80):
        detail_dict = utils.get_html_content_by_id(item['link'], detail_ids)
        item.update(detail_dict)
        for key in item.keys():
            item[key] = utils.drop_html_tag_all(item[key])
        if 'isbn' in item and len(item['isbn'].split()) == 2:
            isbn10, isbn13 = item['isbn'].split()
            item['isbn10'] = isbn10
            item['isbn13'] = isbn13
    res_json.extend(items)

with open(os.path.join(settings.path_to_output, output_filename + '.json'), 'w', encoding='utf8') as file:
    json.dump(res_json, file, ensure_ascii=False, indent=4)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# File              : settings.py
# Author            : JCHRYS <jchrys@me.com>
# Date              : 04.01.2020
# Last Modified Date: 06.01.2020
# Last Modified By  : JCHRYS <jchrys@me.com>
#################################
##### NAVER BOOK API PARSER #####
#################################
import os

# Ouput Folder
path_to_output = os.path.join(os.getcwd(), 'nb')


# API_URLS
default_url = "https://openapi.naver.com/v1/search/book.json"

# API KEYS
client_id = 'dnDZOXWtoDfDYS0zPt10'
client_secret = 'fYGT4Tfb8C'

default_headers = {
    "X-Naver-Client-Id": client_id,
    "X-Naver-Client-Secret": client_secret,
}

query: str = ""
item_per_page : int = 100
page_num : int = 1

default_params = {
    "query": query,
    "display": item_per_page,
    "start": page_num,
    #sort: "sim",
}



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# File              : requester.py
# Author            : JCHRYS <jchrys@me.com>
# Date              : 04.01.2020
# Last Modified Date: 04.01.2020
# Last Modified By  : JCHRYS <jchrys@me.com>
import requests

class Singletone():
    __instance = None
    
    @classmethod
    def __get_instance(cls):
        return cls.__instance

    @classmethod
    def instance(cls, *args, **kargs):
        cls.__instance = cls(*args, **kargs)
        cls.instance = cls.__getInstance
        return cls.__instance


class BaseClass():

    def __init__(self, default_headers, default_params, default_url):
        self.headers = default_headers
        self.params = default_params
        self.url = default_url

    
    def search(self, string):
        if string is None or string == '':
            raise Exception("keyword is empty")
            return None # ERROR NO SEARCH TEXT
        context = {
                "query": string
                }
        return requests.get(self.url, headers = self.headers, params = dict(self.params, **context))

    def search_title(self, string):
        pass

    def search_author(self, string):
        pass

    def search_text(self, string):
        pass

class Request(BaseClass, Singletone):
    pass


if __name__ == '__main__':
    from NBCrawler import settings
    requester = Request(settings.default_headers, 
                      settings.default_params, 
                      settings.default_url
                      )
    res = requester.search("자바")
    print(res.content.decode('utf-8'))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# File              : setup.py
# Author            : JCHRYS <jchrys@me.com>
# Date              : 06.01.2020
# Last Modified Date: 06.01.2020
# Last Modified By  : JCHRYS <jchrys@me.com>
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()


setup(
        name="nbs", 
        version="0.0.1", 
        packages= find_packages(),
        description="Book information crawler using 'NAVER BOOKS API'",
        author="JCHRYS",
        author_email="jchrys@me.com",
        long_description=long_description,
        url='https://github.com/jchrys/NBCrawler',
        install_requires=["requests",
            "bs4", 
            "tqdm",
            ],
        python_requires='>=3.6',
        classifiers=[
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            ]
        )
